pub enum CreateBotError {
BadRequest(String),
Forbidden(String),
NotFound(String),
ResourceLimitExceeded(String),
ServiceFailure(String),
ServiceUnavailable(String),
ThrottledClient(String),
UnauthorizedClient(String),
}Expand description
Errors returned by CreateBot
Variants
BadRequest(String)
The input parameters don't match the service's restrictions.
Forbidden(String)
The client is permanently forbidden from making the request. For example, when a user tries to create an account from an unsupported Region.
NotFound(String)
One or more of the resources in the request does not exist in the system.
ResourceLimitExceeded(String)
The request exceeds the resource limit.
ServiceFailure(String)
The service encountered an unexpected error.
The service is currently unavailable.
ThrottledClient(String)
The client exceeded its request rate limit.
The client is not currently authorized to make the request.
Implementations
Sourceimpl CreateBotError
impl CreateBotError
pub fn from_response(res: BufferedHttpResponse) -> RusotoError<CreateBotError>