pub enum CreateChannelError {
BadRequest(String),
Conflict(String),
Forbidden(String),
ResourceLimitExceeded(String),
ServiceFailure(String),
ServiceUnavailable(String),
ThrottledClient(String),
UnauthorizedClient(String),
}Expand description
Errors returned by CreateChannel
Variants
BadRequest(String)
The input parameters don't match the service's restrictions.
Conflict(String)
The request could not be processed because of conflict in the current state of the resource.
Forbidden(String)
The client is permanently forbidden from making the request.
ResourceLimitExceeded(String)
The request exceeds the resource limit.
ServiceFailure(String)
The service encountered an unexpected error.
The service is currently unavailable.
ThrottledClient(String)
The client exceeded its request rate limit.
The client is not currently authorized to make the request.
Implementations
Sourceimpl CreateChannelError
impl CreateChannelError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<CreateChannelError>